@@ -31,7 +31,7 @@
 #'
 #' - [tk_augment_timeseries_signature()] - Group-wise augmentation of timestamp features
 #' - [tk_augment_holiday_signature()] - Group-wise augmentation of holiday features
-#' - [tk_augment_roll_apply()] - Group-wise augmentation of rolling functions
+#' - [tk_augment_slidify()] - Group-wise augmentation of rolling functions
 #' - [tk_augment_lags()] - Group-wise augmentation of lagged data
 #' - [tk_augment_differences()] - Group-wise augmentation of differenced data
 #' - [tk_augment_fourier()] - Group-wise augmentation of fourier series
@@ -90,6 +90,7 @@ tk_augment_differences.data.frame <- function(.data,
             lag        = lag_val,
             difference = diff_val,
             log        = .log,
+            silent     = TRUE,
             .ns        = "timetk"
         )
     }
